@@ -94,6 +94,7 @@ class TaSignals:
         df['ema100'] = df[key].ewm(span=100, adjust=False).mean()
         df['ema200'] = df[key].ewm(span=200, adjust=False).mean()
         df['ema8_slope'] = df['ema8'].rolling(window=self.window).apply(self.get_slope, raw=True)
+        df['ema34_slope'] = df['ema34'].rolling(window=self.window).apply(self.get_slope, raw=True)
 
         data = {'ema20': df['ema20'].iloc[-1], 'ema50': df['ema50'].iloc[-1], 'ema100': df['ema100'].iloc[-1], 'ema200': df['ema200'].iloc[-1]}
         data = [
@@ -120,6 +121,9 @@ class TaSignals:
         df['rsi_slope'] = df['rsi'].rolling(window=self.window).apply(self.get_slope, raw=True)
         data = {'rsi': df['rsi'].iloc[-1]}
         data = [
+            {'key': 'rsi_under_50', 'value': 'RSI under 50' if df['rsi'].iloc[-1] < 50 else False},
+            {'key': 'rsi_under_60', 'value': 'RSI under 60' if df['rsi'].iloc[-1] < 60 else False},
+            {'key': 'rsi_under_65', 'value': 'RSI under 65' if df['rsi'].iloc[-1] < 65 else False},
             {'key': 'rsi_rising', 'value': 'RSI is rising' if df['rsi_slope'].iloc[-1] > 0 and df['rsi_slope'].iloc[-1] < 10 else False},
             {'key': 'rsi_rising_fast', 'value': 'RSI is rising fast' if df['rsi_slope'].iloc[-1] > 10 else False},
             {'key': 'rsi_dropping', 'value': 'RSI is dropping' if df['rsi_slope'].iloc[-1] < 0 and df['rsi_slope'].iloc[-1] > 10 else False},
